@@ -1,10 +1,11 @@
+from __future__ import annotations
+
 import json
 import logging
+import re
 from collections import defaultdict
 from copy import deepcopy
-from typing import Dict, List
-
-import re
+from typing import TYPE_CHECKING, Any
 
 from checkov.common.bridgecrew.integration_features.base_integration_feature import BaseIntegrationFeature
 from checkov.common.bridgecrew.platform_integration import bc_integration
@@ -12,16 +13,21 @@ from checkov.common.bridgecrew.severities import Severities
 from checkov.common.checks_infra.checks_parser import NXGraphCheckParser
 from checkov.common.checks_infra.registry import Registry, get_graph_checks_registry
 
+if TYPE_CHECKING:
+    from checkov.common.bridgecrew.platform_integration import BcPlatformIntegration
+    from checkov.common.output.record import Record
+    from checkov.common.output.report import Report
+
 # service-provider::service-name::data-type-name
 CFN_RESOURCE_TYPE_IDENTIFIER = re.compile(r"^[a-zA-Z0-9]+::[a-zA-Z0-9]+::[a-zA-Z0-9]+$")
 
 
 class CustomPoliciesIntegration(BaseIntegrationFeature):
-    def __init__(self, bc_integration):
-        super().__init__(bc_integration, order=1)  # must be after policy metadata
+    def __init__(self, bc_integration: BcPlatformIntegration) -> None:
+        super().__init__(bc_integration=bc_integration, order=1)  # must be after policy metadata
         self.platform_policy_parser = NXGraphCheckParser()
         self.policies_url = f"{self.bc_integration.api_url}/api/v1/policies/table/data"
-        self.bc_cloned_checks: Dict[str, List[dict]] = defaultdict(list)
+        self.bc_cloned_checks: dict[str, list[dict[str, Any]]] = defaultdict(list)
 
     def is_valid(self) -> bool:
         return (
@@ -30,7 +36,7 @@ class CustomPoliciesIntegration(BaseIntegrationFeature):
             and not self.integration_feature_failures
         )
 
-    def pre_scan(self):
+    def pre_scan(self) -> None:
         try:
             if not self.bc_integration.customer_run_config_response:
                 logging.debug('In the pre-scan for custom policies, but nothing was fetched from the platform')
@@ -71,7 +77,7 @@ class CustomPoliciesIntegration(BaseIntegrationFeature):
             logging.debug("Scanning without applying custom policies from the platform.", exc_info=True)
 
     @staticmethod
-    def _convert_raw_check(policy):
+    def _convert_raw_check(policy: dict[str, Any]) -> dict[str, Any]:
         metadata = {
             'id': policy['id'],
             'name': policy['title'],
@@ -84,16 +90,16 @@ class CustomPoliciesIntegration(BaseIntegrationFeature):
         }
         return check
 
-    def post_runner(self, scan_reports):
+    def post_runner(self, scan_report: Report) -> None:
         if self.bc_cloned_checks:
-            scan_reports.failed_checks = self.extend_records_with_cloned_policies(scan_reports.failed_checks)
-            scan_reports.passed_checks = self.extend_records_with_cloned_policies(scan_reports.passed_checks)
-            scan_reports.skipped_checks = self.extend_records_with_cloned_policies(scan_reports.skipped_checks)
+            scan_report.failed_checks = self.extend_records_with_cloned_policies(scan_report.failed_checks)
+            scan_report.passed_checks = self.extend_records_with_cloned_policies(scan_report.passed_checks)
+            scan_report.skipped_checks = self.extend_records_with_cloned_policies(scan_report.skipped_checks)
 
-    def extend_records_with_cloned_policies(self, records):
+    def extend_records_with_cloned_policies(self, records: list[Record]) -> list[Record]:
         bc_check_ids = [record.bc_check_id for record in records]
         for idx, bc_check_id in enumerate(bc_check_ids):
-            cloned_policies = self.bc_cloned_checks.get(bc_check_id, [])
+            cloned_policies = self.bc_cloned_checks.get(bc_check_id, [])  # type:ignore[arg-type]  # bc_check_id can be None
             for cloned_policy in cloned_policies:
                 new_record = deepcopy(records[idx])
                 new_record.check_id = cloned_policy['id']
