@@ -1,7 +1,7 @@
-import itertools
-from typing import List, Optional, Dict, Any, Tuple
+from __future__ import annotations
 
-from networkx import DiGraph
+import itertools
+from typing import List, Optional, Dict, Any, Tuple, TYPE_CHECKING
 
 from checkov.common.graph.checks_infra.enums import SolverType
 from checkov.common.graph.checks_infra.solvers.base_solver import BaseSolver
@@ -9,9 +9,11 @@ from checkov.common.checks_infra.solvers.attribute_solvers.base_attribute_solver
 from checkov.common.checks_infra.solvers.complex_solvers.base_complex_solver import BaseComplexSolver
 from checkov.common.checks_infra.solvers.connections_solvers.base_connection_solver import BaseConnectionSolver
 from checkov.common.checks_infra.solvers.filter_solvers.base_filter_solver import BaseFilterSolver
-
 from checkov.common.graph.graph_builder.graph_components.attribute_names import CustomAttributes
 
+if TYPE_CHECKING:
+    from networkx import DiGraph
+
 
 class ComplexConnectionSolver(BaseConnectionSolver):
     def __init__(self, solvers: Optional[List[BaseSolver]], operator: str) -> None:
