@@ -1,10 +1,13 @@
-from abc import abstractmethod
-from typing import Tuple, List, Dict, Any
+from __future__ import annotations
 
-from networkx import DiGraph
+from abc import abstractmethod
+from typing import Tuple, List, Dict, Any, TYPE_CHECKING
 
 from checkov.common.graph.checks_infra.enums import SolverType
 
+if TYPE_CHECKING:
+    from networkx import DiGraph
+
 
 class BaseSolver:
     operator = ""  # noqa: CCE003  # a static attribute
