@@ -1,3 +1,4 @@
+from typing import Any, Tuple, Dict
 
 from checkov.common.models.enums import CheckResult
 from checkov.github_actions.checks.base_github_action_check import BaseGithubActionsCheck
@@ -12,13 +13,15 @@ class SuspectCurlInScript(BaseGithubActionsCheck):
             name=name,
             id=id,
             block_type=BlockType.ARRAY,
-            supported_entities=['jobs','jobs.*.steps[]']
+            supported_entities=('jobs', 'jobs.*.steps[]')
         )
 
-    def scan_entity_conf(self, conf):
+    def scan_entity_conf(self, conf: Dict[str, Any]) -> Tuple[CheckResult, Dict[str, Any]]:
+        if not isinstance(conf, dict):
+            return CheckResult.UNKNOWN, conf
         run = conf.get("run", "")
         if "curl" in run:
-            badstuff = ['curl','secret']
+            badstuff = ('curl', 'secret')
             lines = run.split("\n")
             for line in lines:
                 if all(x in line for x in badstuff):
