@@ -1,4 +1,6 @@
 #!/usr/bin/env python
+from __future__ import annotations
+
 import atexit
 import json
 import logging
@@ -7,12 +9,10 @@ import shutil
 import signal
 import sys
 from pathlib import Path
-from typing import Any, List, Optional
+from typing import Any, List, Optional, TYPE_CHECKING
 
 import argcomplete
 import configargparse
-from configargparse import ArgumentParser
-from configargparse import Namespace
 from urllib3.exceptions import MaxRetryError
 
 import checkov.logging_init  # noqa  # should be imported before the others to ensure correct logging setup
@@ -30,8 +30,9 @@ from checkov.common.bridgecrew.integration_features.features.repo_config_integra
 from checkov.common.bridgecrew.integration_features.integration_feature_registry import integration_feature_registry
 from checkov.common.bridgecrew.platform_integration import bc_integration
 from checkov.common.goget.github.get_git import GitGetter
+from checkov.common.images.image_referencer import enable_image_referencer
 from checkov.common.output.baseline import Baseline
-from checkov.common.output.report import CheckType
+from checkov.common.bridgecrew.check_type import CheckType
 from checkov.common.runners.runner_registry import RunnerRegistry, OUTPUT_CHOICES
 from checkov.common.util import prompt
 from checkov.common.util.banner import banner as checkov_banner
@@ -62,6 +63,10 @@ from checkov.yaml_doc.runner import Runner as yaml_runner
 from checkov.bicep.runner import Runner as bicep_runner
 from checkov.openapi.runner import Runner as openapi_runner
 from checkov.circleci_pipelines.runner import Runner as circleci_pipelines_runner
+
+if TYPE_CHECKING:
+    from configargparse import ArgumentParser, Namespace
+
 signal.signal(signal.SIGINT, lambda x, y: sys.exit(''))
 
 outer_registry = None
@@ -107,7 +112,7 @@ def run(banner: str = checkov_banner, argv: List[str] = sys.argv[1:]) -> Optiona
     argcomplete.autocomplete(parser)
     config = parser.parse_args(argv)
 
-    normalize_config(config)
+    normalize_config(config, parser)
 
     logger.debug(f'Checkov version: {version}')
     logger.debug(f'Python executable: {sys.executable}')
@@ -139,6 +144,12 @@ def run(banner: str = checkov_banner, argv: List[str] = sys.argv[1:]) -> Optiona
     if config.var_file:
         config.var_file = [os.path.abspath(f) for f in config.var_file]
 
+    run_image_referencer = enable_image_referencer(
+        bc_integration=bc_integration,
+        frameworks=config.framework,
+        skip_frameworks=config.skip_framework,
+    )
+
     runner_filter = RunnerFilter(framework=config.framework, skip_framework=config.skip_framework, checks=config.check,
                                  skip_checks=config.skip_check, include_all_checkov_policies=config.include_all_checkov_policies,
                                  download_external_modules=bool(convert_str_to_bool(config.download_external_modules)),
@@ -147,7 +158,10 @@ def run(banner: str = checkov_banner, argv: List[str] = sys.argv[1:]) -> Optiona
                                  runners=checkov_runners, excluded_paths=excluded_paths,
                                  all_external=config.run_all_external_checks, var_files=config.var_file,
                                  skip_cve_package=config.skip_cve_package, show_progress_bar=not config.quiet,
-                                 secrets_scan_file_type=config.secrets_scan_file_type)
+                                 secrets_scan_file_type=config.secrets_scan_file_type,
+                                 use_enforcement_rules=config.use_enforcement_rules,
+                                 run_image_referencer=run_image_referencer)
+
     if outer_registry:
         runner_registry = outer_registry
         runner_registry.runner_filter = runner_filter
@@ -245,6 +259,9 @@ def run(banner: str = checkov_banner, argv: List[str] = sys.argv[1:]) -> Optiona
 
     runner_filter.excluded_paths = runner_filter.excluded_paths + list(repo_config_integration.skip_paths)
 
+    if config.use_enforcement_rules:
+        runner_filter.apply_enforcement_rules(repo_config_integration.code_category_configs)
+
     if config.list:
         print_checks(frameworks=config.framework, use_bc_ids=config.output_bc_ids,
                      include_all_checkov_policies=config.include_all_checkov_policies, filtered_policy_ids=runner_filter.filtered_policy_ids)
@@ -305,6 +322,7 @@ def run(banner: str = checkov_banner, argv: List[str] = sys.argv[1:]) -> Optiona
         runner = sca_image_runner()
         result = runner.run(root_folder='', image_id=config.docker_image,
                             dockerfile_path=config.dockerfile_path, runner_filter=runner_filter)
+        integration_feature_registry.run_post_runner(result)
         bc_integration.persist_repository(os.path.dirname(config.dockerfile_path), files=files)
         bc_integration.persist_scan_results([result])
         bc_integration.persist_image_scan_results(runner.raw_report, config.dockerfile_path, config.docker_image,
@@ -402,10 +420,10 @@ def add_parser_args(parser: ArgumentParser) -> None:
                     'Each item may be either a Checkov check ID (CKV_AWS_123), a BC check ID (BC_AWS_GENERAL_123), or '
                     'a severity (LOW, MEDIUM, HIGH, CRITICAL). If you use a severity, then all checks equal to or '
                     'above the lowest severity in the list will be included. This option can be combined with '
-                    '--skip-check. If it is, priority is given to checks explicitly listed by ID or wildcard over '
-                    'checks listed by severity. For example, if you use --check CKV_123 and --skip-check LOW, then '
-                    'CKV_123 will run even if it is a LOW severity. In the case of a tie (e.g., --check MEDIUM and '
-                    '--skip-check HIGH for a medium severity check), then the check will be skipped. If you use a '
+                    '--skip-check. If it is, then the logic is to first take all checks that match this list, and then '
+                    'remove all checks that match the skip list. For example, if you use --check CKV_123 and '
+                    '--skip-check LOW, then CKV_123 will not run if it is a LOW severity. Similarly, if you use '
+                    '--check CKV_789 --skip-check MEDIUM, then CKV_789 will run if it is a HIGH severity. If you use a '
                     'check ID here along with an API key, and the check is not part of the BC / PC platform, then the '
                     'check will still be run (see --include-all-checkov-policies for more info).',
                action='append', default=None,
@@ -430,26 +448,26 @@ def add_parser_args(parser: ArgumentParser) -> None:
                     'overrides this option, except for the case when a result does not match either of the soft fail '
                     'or hard fail criteria, in which case this flag determines the result.', action='store_true')
     parser.add('--soft-fail-on',
-                        help='Exits with a 0 exit code if only the specified items fail. Enter one or more items '
-                             'separated by commas. Each item may be either a Checkov check ID (CKV_AWS_123), a BC '
-                             'check ID (BC_AWS_GENERAL_123), or a severity (LOW, MEDIUM, HIGH, CRITICAL). If you use '
-                             'a severity, then any severity equal to or less than the highest severity in the list '
-                             'will result in a soft fail. This option may be used with --hard-fail-on, using the same '
-                             'priority logic described in --check and --skip-check options above, with --hard-fail-on '
-                             'taking precedence in a tie. If a given result does not meet the --soft-fail-on nor '
-                             'the --hard-fail-on criteria, then the default is to hard fail',
-                        action='append',
-                        default=None)
+               help='Exits with a 0 exit code if only the specified items fail. Enter one or more items '
+                    'separated by commas. Each item may be either a Checkov check ID (CKV_AWS_123), a BC '
+                    'check ID (BC_AWS_GENERAL_123), or a severity (LOW, MEDIUM, HIGH, CRITICAL). If you use '
+                    'a severity, then any severity equal to or less than the highest severity in the list '
+                    'will result in a soft fail. This option may be used with --hard-fail-on, using the same '
+                    'priority logic described in --check and --skip-check options above, with --hard-fail-on '
+                    'taking precedence in a tie. If a given result does not meet the --soft-fail-on nor '
+                    'the --hard-fail-on criteria, then the default is to hard fail',
+               action='append',
+               default=None)
     parser.add('--hard-fail-on',
-                        help='Exits with a non-zero exit code for specified checks. Enter one or more items '
-                             'separated by commas. Each item may be either a Checkov check ID (CKV_AWS_123), a BC '
-                             'check ID (BC_AWS_GENERAL_123), or a severity (LOW, MEDIUM, HIGH, CRITICAL). If you use a '
-                             'severity, then any severity equal to or greater than the lowest severity in the list will '
-                             'result in a hard fail. This option can be used with --soft-fail-on, using the same '
-                             'priority logic described in --check and --skip-check options above, with --hard-fail-on '
-                             'taking precedence in a tie.',
-                        action='append',
-                        default=None)
+               help='Exits with a non-zero exit code for specified checks. Enter one or more items '
+                    'separated by commas. Each item may be either a Checkov check ID (CKV_AWS_123), a BC '
+                    'check ID (BC_AWS_GENERAL_123), or a severity (LOW, MEDIUM, HIGH, CRITICAL). If you use a '
+                    'severity, then any severity equal to or greater than the lowest severity in the list will '
+                    'result in a hard fail. This option can be used with --soft-fail-on, using the same '
+                    'priority logic described in --check and --skip-check options above, with --hard-fail-on '
+                    'taking precedence in a tie.',
+               action='append',
+               default=None)
     parser.add('--bc-api-key', env_var='BC_API_KEY', sanitize=True,
                help='Bridgecrew API key or Prisma Cloud Access Key (see --prisma-api-url)')
     parser.add('--prisma-api-url', env_var='PRISMA_API_URL', default=None,
@@ -467,6 +485,17 @@ def add_parser_args(parser: ArgumentParser) -> None:
                     'custom policies and suppressions if using an API token. Note: it will prevent BC platform IDs from '
                     'being available in Checkov.',
                action='store_true')
+    parser.add('--use-enforcement-rules', action='store_true',
+               help='Use the Enforcement rules configured in the platform for hard / soft fail logic. With this option, '
+                    'the enforcement rule matching this repo, or the default rule if there is no match, will determine '
+                    'this behavior: any check with a severity below the selected rule\'s soft-fail threshold will be '
+                    'skipped; any check with a severity equal to or greater than the rule\'s hard-fail threshold will '
+                    'be part of the hard-fail list, and any check in between will be part of the soft-fail list. For '
+                    'example, if the given enforcement rule has a hard-fail value of HIGH and a soft-fail value of MEDIUM,'
+                    'this is the equivalent of using the flags `--skip-check LOW --hard-fail-on HIGH`. You can use --check, '
+                    '--skip-check, --soft-fail, --soft-fail-on, or --hard-fail-on to override portions of an enforcement rule. '
+                    'Note, however, that the logic of applying the --check list and then the --skip-check list (as described '
+                    'above under --check) still applies here. Requires a BC or PC platform API key.')
     parser.add('--no-guide', action='store_true',
                default=False,
                help='Deprecated - use --skip-download')
@@ -485,7 +514,7 @@ def add_parser_args(parser: ArgumentParser) -> None:
     parser.add('--var-file', action='append',
                help='Variable files to load in addition to the default files (see '
                     'https://www.terraform.io/docs/language/values/variables.html#variable-definitions-tfvars-files).'
-                    'Currently only supported for source Terraform (.tf file), and Helm chart scans.' 
+                    'Currently only supported for source Terraform (.tf file), and Helm chart scans.'
                     'Requires using --directory, not --file.')
     parser.add('--external-modules-download-path',
                help="set the path for the download external terraform modules",
@@ -516,9 +545,12 @@ def add_parser_args(parser: ArgumentParser) -> None:
         ),
         default=None,
     )
-    parser.add('--output-baseline-as-skipped',
+    parser.add(
+        '--output-baseline-as-skipped',
         help="output checks that are skipped due to baseline file presence",
-        action='store_true', default=False)
+        action='store_true',
+        default=False,
+    )
     parser.add('--skip-cve-package',
                help='filter scan to run on all packages but a specific package identifier (denylist), You can '
                     'specify this argument multiple times to skip multiple packages', action='append', default=None)
@@ -546,7 +578,7 @@ def get_external_checks_dir(config: Any) -> Any:
     return external_checks_dir
 
 
-def normalize_config(config: Namespace) -> None:
+def normalize_config(config: Namespace, parser: ExtArgumentParser) -> None:
     if config.no_guide:
         logger.warning('--no-guide is deprecated and will be removed in a future release. Use --skip-download instead')
         config.skip_download = True
@@ -566,6 +598,9 @@ def normalize_config(config: Namespace) -> None:
         logger.debug('No API key present; setting include_all_checkov_policies to True')
         config.include_all_checkov_policies = True
 
+    if config.use_enforcement_rules and not config.bc_api_key:
+        parser.error('Must specify an API key with --use-enforcement-rules')
+
     if config.policy_metadata_filter and not (config.bc_api_key and config.prisma_api_url):
         logger.warning('--policy-metadata-filter flag was used without a Prisma Cloud API key. Policy filtering will be skipped.')
 
