@@ -3,8 +3,9 @@ from __future__ import annotations
 import logging
 import fnmatch
 from collections.abc import Iterable
-from typing import Set, Optional, Union, List, TYPE_CHECKING
+from typing import Any, Set, Optional, Union, List, TYPE_CHECKING, Dict
 
+from checkov.common.bridgecrew.code_categories import CodeCategoryMapping, CodeCategoryConfiguration
 from checkov.common.bridgecrew.severities import Severity, Severities
 from checkov.common.util.consts import DEFAULT_EXTERNAL_MODULES_DIR
 from checkov.common.util.type_forcers import convert_csv_string_arg_to_list
@@ -35,14 +36,19 @@ class RunnerFilter(object):
             all_external: bool = False,
             var_files: Optional[List[str]] = None,
             skip_cve_package: Optional[List[str]] = None,
+            use_enforcement_rules: bool = False,
             filtered_policy_ids: Optional[List[str]] = None,
             show_progress_bar: Optional[bool] = True,
-            secrets_scan_file_type: Optional[List[str]] = None
+            secrets_scan_file_type: Optional[List[str]] = None,
+            run_image_referencer: bool = False
     ) -> None:
 
         checks = convert_csv_string_arg_to_list(checks)
         skip_checks = convert_csv_string_arg_to_list(skip_checks)
 
+        self.use_enforcement_rules = use_enforcement_rules
+        self.enforcement_rule_configs: Optional[Dict[str, Severity]] = None
+
         # we will store the lowest value severity we find in checks, and the highest value we find in skip-checks
         # so the logic is "run all checks >= severity" and/or "skip all checks <= severity"
         self.check_threshold = None
@@ -90,6 +96,15 @@ class RunnerFilter(object):
         self.skip_cve_package = skip_cve_package
         self.filtered_policy_ids = filtered_policy_ids or []
         self.secrets_scan_file_type = secrets_scan_file_type
+        self.run_image_referencer = run_image_referencer
+
+    def apply_enforcement_rules(self, enforcement_rule_configs: Dict[str, CodeCategoryConfiguration]) -> None:
+        self.enforcement_rule_configs = {}
+        for report_type, code_category in CodeCategoryMapping.items():
+            config = enforcement_rule_configs.get(code_category)
+            if not config:
+                raise Exception(f'Could not find an enforcement rule config for category {code_category} (runner: {report_type})')
+            self.enforcement_rule_configs[report_type] = config.soft_fail_threshold
 
     def should_run_check(
         self,
@@ -97,6 +112,7 @@ class RunnerFilter(object):
         check_id: str | None = None,
         bc_check_id: str | None = None,
         severity: Severity | None = None,
+        report_type: str | None = None
     ) -> bool:
         if check:
             check_id = check.id
@@ -105,9 +121,24 @@ class RunnerFilter(object):
 
         assert check_id is not None  # nosec (for mypy (and then for bandit))
 
-        run_severity = severity and self.check_threshold and severity.level >= self.check_threshold.level
+        # apply enforcement rules if specified, but let --check/--skip-check with a severity take priority
+        if self.use_enforcement_rules and report_type:
+            if not self.check_threshold and not self.skip_check_threshold:
+                check_threshold = self.enforcement_rule_configs[report_type]  # type:ignore[index] # mypy thinks it might be null
+                skip_check_threshold = None
+            else:
+                check_threshold = self.check_threshold
+                skip_check_threshold = self.skip_check_threshold
+        else:
+            if self.use_enforcement_rules:
+                # this is a warning for us (but there is nothing the user can do about it)
+                logging.debug(f'Use enforcement rules is true, but check {check_id} was not passed to the runner filter with a report type')
+            check_threshold = self.check_threshold
+            skip_check_threshold = self.skip_check_threshold
+
+        run_severity = severity and check_threshold and severity.level >= check_threshold.level
         explicit_run = self.checks and self.check_matches(check_id, bc_check_id, self.checks)
-        implicit_run = not self.checks and not self.check_threshold
+        implicit_run = not self.checks and not check_threshold
         is_external = RunnerFilter.is_external_check(check_id)
         is_policy_filtered = self.is_policy_filtered(check_id)
         # True if this check is present in the allow list, or if there is no allow list
@@ -127,7 +158,7 @@ class RunnerFilter(object):
         if not is_policy_filtered:
             should_run_check = False
 
-        skip_severity = severity and self.skip_check_threshold and severity.level <= self.skip_check_threshold.level
+        skip_severity = severity and skip_check_threshold and severity.level <= skip_check_threshold.level
         explicit_skip = self.skip_checks and self.check_matches(check_id, bc_check_id, self.skip_checks)
 
         should_skip_check = (
@@ -171,3 +202,52 @@ class RunnerFilter(object):
         if not self.filtered_policy_ids:
             return True
         return check_id in self.filtered_policy_ids
+    
+    def to_dict(self) -> Dict[str, Any]:
+        result: Dict[str, Any] = {}
+        for key, value in self.__dict__.items():
+            result[key] = value
+        return result
+
+    @staticmethod
+    def from_dict(obj: Dict[str, Any]) -> RunnerFilter:
+        framework = obj.get('framework')
+        checks = obj.get('checks')
+        skip_checks = obj.get('skip_checks')
+        include_all_checkov_policies = obj.get('include_all_checkov_policies')
+        if include_all_checkov_policies is None:
+            include_all_checkov_policies = True
+        download_external_modules = obj.get('download_external_modules')
+        if download_external_modules is None:
+            download_external_modules = False
+        external_modules_download_path = obj.get('external_modules_download_path')
+        if external_modules_download_path is None:
+            external_modules_download_path = DEFAULT_EXTERNAL_MODULES_DIR
+        evaluate_variables = obj.get('evaluate_variables')
+        if evaluate_variables is None:
+            evaluate_variables = True
+        runners = obj.get('runners')
+        skip_framework = obj.get('skip_framework')
+        excluded_paths = obj.get('excluded_paths')
+        all_external = obj.get('all_external')
+        if all_external is None:
+            all_external = False
+        var_files = obj.get('var_files')
+        skip_cve_package = obj.get('skip_cve_package')
+        use_enforcement_rules = obj.get('use_enforcement_rules')
+        if use_enforcement_rules is None:
+            use_enforcement_rules = False
+        filtered_policy_ids = obj.get('filtered_policy_ids')
+        show_progress_bar = obj.get('show_progress_bar')
+        if show_progress_bar is None:
+            show_progress_bar = True
+        secrets_scan_file_type = obj.get('secrets_scan_file_type')
+        run_image_referencer = obj.get('run_image_referencer')
+        if run_image_referencer is None:
+            run_image_referencer = False
+        runner_filter = RunnerFilter(framework, checks, skip_checks, include_all_checkov_policies,
+                                     download_external_modules, external_modules_download_path, evaluate_variables,
+                                     runners, skip_framework, excluded_paths, all_external, var_files,
+                                     skip_cve_package, use_enforcement_rules, filtered_policy_ids, show_progress_bar,
+                                     secrets_scan_file_type, run_image_referencer)
+        return runner_filter
