@@ -4,6 +4,7 @@ import asyncio
 import json
 import logging
 import os.path
+from collections.abc import Iterable
 from pathlib import Path
 from typing import Optional, List, Union, Dict, Any
 
@@ -15,8 +16,11 @@ from checkov.common.bridgecrew.vulnerability_scanning.image_scanner import image
 from checkov.common.bridgecrew.vulnerability_scanning.integrations.docker_image_scanning import \
     docker_image_scanning_integration
 from checkov.common.images.image_referencer import ImageReferencer, Image
-from checkov.common.output.report import Report, CheckType, merge_reports
+from checkov.common.output.report import Report, merge_reports
+from checkov.common.bridgecrew.check_type import CheckType
+from checkov.common.output.common import ImageDetails
 from checkov.common.runners.base_runner import filter_ignored_paths, strtobool
+from checkov.common.sca.output import parse_vulns_to_records, get_license_statuses
 from checkov.common.util.file_utils import compress_file_gzip_base64
 from checkov.common.util.dockerfile import is_docker_file
 from checkov.runner_filter import RunnerFilter
@@ -27,7 +31,7 @@ class Runner(PackageRunner):
     check_type = CheckType.SCA_IMAGE  # noqa: CCE003  # a static attribute
 
     def __init__(self) -> None:
-        super().__init__()
+        super().__init__(report_type=self.check_type)
         self._check_class: Optional[str] = None
         self._code_repo_path: Optional[Path] = None
         self._check_class = f"{image_scanner.__module__}.{image_scanner.__class__.__qualname__}"
@@ -130,13 +134,13 @@ class Runner(PackageRunner):
         if not runner_filter.show_progress_bar:
             self.pbar.turn_off_progress_bar()
 
-        report = Report(self.check_type)
+        self._code_repo_path = Path(root_folder) if root_folder else None
 
         if "dockerfile_path" in kwargs and "image_id" in kwargs:
             dockerfile_path = kwargs['dockerfile_path']
             image_id = kwargs['image_id']
             return self.get_image_id_report(dockerfile_path, image_id, runner_filter)
-
+        report = Report(self.check_type)
         if not files and not root_folder:
             logging.debug("No resources to scan.")
             return report
@@ -147,11 +151,10 @@ class Runner(PackageRunner):
                 self.iterate_image_files(file, report, runner_filter)
                 self.pbar.update()
             self.pbar.close()
-
         if root_folder:
             for root, d_names, f_names in os.walk(root_folder):
-                filter_ignored_paths(root, d_names, runner_filter.excluded_paths)
-                filter_ignored_paths(root, f_names, runner_filter.excluded_paths)
+                filter_ignored_paths(root, d_names, runner_filter.excluded_paths, included_paths=self.included_paths())
+                filter_ignored_paths(root, f_names, runner_filter.excluded_paths, included_paths=self.included_paths())
                 for file in f_names:
                     abs_fname = os.path.join(root, file)
                     self.iterate_image_files(abs_fname, report, runner_filter)
@@ -170,9 +173,55 @@ class Runner(PackageRunner):
             if image_referencer.is_workflow_file(abs_fname):
                 images = image_referencer.get_images(file_path=abs_fname)
                 for image in images:
-                    image_report = self.get_image_report(dockerfile_path=abs_fname, image=image,
-                                                         runner_filter=runner_filter)
-                    merge_reports(report, image_report)
+                    if not strtobool(os.getenv('CHECKOV_PRESENT_CACHED_RESULTS', "False")):
+                        image_report = self.get_image_report(dockerfile_path=abs_fname, image=image,
+                                                             runner_filter=runner_filter)
+                        merge_reports(report, image_report)
+                    else:
+                        image_cached_report: dict[str, Any] = self.get_image_cached_results(dockerfile_path=abs_fname, image=image)
+                        if image_cached_report:
+                            report.image_cached_results.append(image_cached_report)
+
+    def get_report_from_scan_result(self, result: Dict[str, Any], dockerfile_path: str, rootless_file_path: str,
+                                    image_details: ImageDetails | None, runner_filter: RunnerFilter) -> Report:
+        report = Report(self.check_type)
+        vulnerabilities = result.get("vulnerabilities", [])
+        packages = result.get("packages", [])
+        license_statuses = get_license_statuses(packages)
+
+        parse_vulns_to_records(
+            report=report,
+            check_class=self._check_class,
+            scanned_file_path=os.path.abspath(dockerfile_path),
+            rootless_file_path=rootless_file_path,
+            runner_filter=runner_filter,
+            vulnerabilities=vulnerabilities,
+            packages=packages,
+            license_statuses=license_statuses,
+            image_details=image_details,
+            report_type=self.report_type,
+        )
+        return report
+
+    def get_image_cached_results(self, dockerfile_path: str, image: Image) -> dict[str, Any]:
+        """
+            :param dockerfile_path: path of a file that might contain a container image
+            :param image: Image object
+            :return: cached_results report
+        """
+        cached_results: Dict[str, Any] = image_scanner.get_scan_results_from_cache(f"image:{image.name}")
+        if not cached_results:
+            # TODO: do we want to trigger a scan in this case?
+            logging.info(f"No cache hit for image {image.name} when getting cached results for dockerfile {dockerfile_path}")
+            return {}
+        payload: dict[str, Any] = docker_image_scanning_integration.create_report(
+            twistcli_scan_result=cached_results,
+            bc_platform_integration=bc_integration,
+            file_path=dockerfile_path,
+            file_content=image.file_path,
+            docker_image_name=image.name,
+            related_resource_id=image.related_resource_id)
+        return payload
 
     def get_image_report(self, dockerfile_path: str, image: Image, runner_filter: RunnerFilter) -> Report:
         """
@@ -182,78 +231,70 @@ class Runner(PackageRunner):
         :param runner_filter:
         :return: vulnerability report
         """
-        report = Report(self.check_type)
-
         # skip complete run, if flag '--check' was used without a CVE check ID
         if runner_filter.checks and all(not check.startswith("CKV_CVE") for check in runner_filter.checks):
-            return report
+            return Report(self.check_type)
 
         cached_results: Dict[str, Any] = image_scanner.get_scan_results_from_cache(f"image:{image.name}")
+
         if cached_results:
             logging.info(f"Found cached scan results of image {image.name}")
-
             self.raw_report = cached_results
             result = cached_results.get('results', [{}])[0]
-            vulnerabilities = result.get("vulnerabilities") or []
             image_id = self.extract_image_short_id(result)
+            image_details = self.get_image_details_from_twistcli_result(scan_result=result, image_id=image_id,
+                                                                        image_name=image.name,
+                                                                        related_resource_id=image.related_resource_id)
+            if self._code_repo_path:
+                try:
+                    dockerfile_path = str(Path(dockerfile_path).relative_to(self._code_repo_path))
+                except ValueError:
+                    # Path.is_relative_to() was implemented in Python 3.9
+                    pass
+            rootless_file_path = dockerfile_path.replace(Path(dockerfile_path).anchor, "", 1)
+            rootless_file_path_to_report = f"{rootless_file_path} ({image.name} lines:{image.start_line}-" \
+                                           f"{image.end_line} ({image_id}))"
+            return self.get_report_from_scan_result(result, dockerfile_path, rootless_file_path_to_report,
+                                                    image_details, runner_filter)
 
-            self.parse_vulns_to_records(
-                report=report,
-                result=result,
-                rootless_file_path=f"{dockerfile_path} ({image.name} lines:{image.start_line}-{image.end_line} ({image_id}))",
-                runner_filter=runner_filter,
-                vulnerabilities=vulnerabilities,
-                packages=[],
-                file_abs_path=os.path.abspath(dockerfile_path),
-            )
-
-            return report
         elif strtobool(os.getenv("CHECKOV_EXPERIMENTAL_IMAGE_REFERENCING", "False")):
             # experimental flag on running image referencers via local twistcli
             image_id = ImageReferencer.inspect(image.name)
             scan_result = self.scan(image_id, dockerfile_path, runner_filter)
             if scan_result is None:
-                return report
+                return Report(self.check_type)
 
             self.raw_report = scan_result
             result = scan_result.get('results', [{}])[0]
-            vulnerabilities = result.get("vulnerabilities") or []
-            self.parse_vulns_to_records(
-                report=report,
-                result=result,
-                rootless_file_path=f"{dockerfile_path} ({image.name} lines:{image.start_line}-{image.end_line} ({image_id}))",
-                runner_filter=runner_filter,
-                vulnerabilities=vulnerabilities,
-                packages=[],
-                file_abs_path=os.path.abspath(dockerfile_path),
-            )
+            rootless_file_path_to_report = f"{dockerfile_path} ({image.name} lines:{image.start_line}-" \
+                                           f"{image.end_line} ({image_id}))"
+            return self.get_report_from_scan_result(result, dockerfile_path, rootless_file_path_to_report, None,
+                                                    runner_filter)
         else:
             logging.info(f"No cache hit for image {image.name}")
 
-        return report
+        return Report(self.check_type)
 
     def get_image_id_report(self, dockerfile_path: str, image_id: str, runner_filter: RunnerFilter) -> Report:
         """
         THIS METHOD HANDLES CUSTOM IMAGE SCANNING THAT COMES DIRECTLY FROM CLI PARAMETERS
         """
-        report = Report(self.check_type)
-
         scan_result = self.scan(image_id, dockerfile_path, runner_filter)
         if scan_result is None:
-            return report
+            return Report(self.check_type)
         self.raw_report = scan_result
         result = scan_result.get('results', [{}])[0]
-        vulnerabilities = result.get("vulnerabilities") or []
-        self.parse_vulns_to_records(
-            report=report,
-            result=result,
-            rootless_file_path=f"{dockerfile_path} ({image_id})",
-            runner_filter=runner_filter,
-            vulnerabilities=vulnerabilities,
-            packages=[],
-            file_abs_path=os.path.abspath(dockerfile_path)
-        )
-        return report
+        image_details = self.get_image_details_from_twistcli_result(scan_result=result, image_id=image_id)
+        if self._code_repo_path:
+            try:
+                dockerfile_path = str(Path(dockerfile_path).relative_to(self._code_repo_path))
+            except ValueError:
+                # Path.is_relative_to() was implemented in Python 3.9
+                pass
+        rootless_file_path = dockerfile_path.replace(Path(dockerfile_path).anchor, "", 1)
+        rootless_file_path_to_report = f"{rootless_file_path} ({image_id})"
+        return self.get_report_from_scan_result(result, dockerfile_path, rootless_file_path_to_report, image_details,
+                                                runner_filter)
 
     def extract_image_short_id(self, scan_result: dict[str, Any]) -> str:
         """Extracts a shortened version of the image ID from the scan result"""
@@ -266,3 +307,23 @@ class Runner(PackageRunner):
         if image_id.startswith("sha256:"):
             return image_id[:17]
         return image_id[:10]
+
+    def get_image_details_from_twistcli_result(self, scan_result: dict[str, Any], image_id: str,
+                                               image_name: str | None = None,
+                                               related_resource_id: str | None = None) -> ImageDetails:
+        image_packages = scan_result.get('packages', [])
+        image_package_types = {
+            f'{package["name"]}@{package["version"]}': package['type']
+            for package in image_packages
+        }
+        return ImageDetails(
+            distro=scan_result.get('distro', ''),
+            distro_release=scan_result.get('distroRelease', ''),
+            package_types=image_package_types,
+            image_id=image_id,
+            name=image_name,
+            related_resource_id=related_resource_id
+        )
+
+    def included_paths(self) -> Iterable[str]:
+        return ['.github', '.circleci']
