@@ -6,12 +6,11 @@ import logging
 import os
 import re
 from pathlib import Path
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, cast
 
-from detect_secrets import SecretsCollection  # type:ignore[import]
-from detect_secrets.core import scan  # type:ignore[import]
-from detect_secrets.core.potential_secret import PotentialSecret  # type:ignore[import]
-from detect_secrets.settings import transient_settings  # type:ignore[import]
+from detect_secrets import SecretsCollection
+from detect_secrets.core import scan
+from detect_secrets.settings import transient_settings
 
 from checkov.common.bridgecrew.integration_features.features.policy_metadata_integration import \
     integration as metadata_integration
@@ -21,7 +20,8 @@ from checkov.common.parallelizer.parallel_runner import parallel_runner
 from checkov.common.models.consts import SUPPORTED_FILE_EXTENSIONS
 from checkov.common.models.enums import CheckResult
 from checkov.common.output.record import Record
-from checkov.common.output.report import Report, CheckType
+from checkov.common.output.report import Report
+from checkov.common.bridgecrew.check_type import CheckType
 from checkov.common.runners.base_runner import BaseRunner, filter_ignored_paths
 from checkov.common.runners.base_runner import ignored_directories
 from checkov.common.typing import _CheckResult
@@ -32,7 +32,10 @@ from checkov.runner_filter import RunnerFilter
 
 if TYPE_CHECKING:
     from checkov.common.util.tqdm_utils import ProgressBar
+    from detect_secrets.core.potential_secret import PotentialSecret
 
+SOURCE_CODE_EXTENSION = ['.py', '.js', '.properties', '.pem', '.php', '.xml', '.ts', '.env', '.java', '.rb',
+                         'go', 'cs', '.txt']
 SECRET_TYPE_TO_ID = {
     'Artifactory Credentials': 'CKV_SECRET_1',
     'AWS Access Key': 'CKV_SECRET_2',
@@ -43,7 +46,7 @@ SECRET_TYPE_TO_ID = {
     'IBM Cloud IAM Key': 'CKV_SECRET_7',
     'IBM COS HMAC Credentials': 'CKV_SECRET_8',
     'JSON Web Token': 'CKV_SECRET_9',
-    # 'Secret Keyword': 'CKV_SECRET_10',
+    'Secret Keyword': 'CKV_SECRET_10',
     'Mailchimp Access Key': 'CKV_SECRET_11',
     'NPM tokens': 'CKV_SECRET_12',
     'Private Key': 'CKV_SECRET_13',
@@ -58,8 +61,7 @@ CHECK_ID_TO_SECRET_TYPE = {v: k for k, v in SECRET_TYPE_TO_ID.items()}
 
 ENTROPY_KEYWORD_LIMIT = 3
 PROHIBITED_FILES = ['Pipfile.lock', 'yarn.lock', 'package-lock.json', 'requirements.txt']
-ADDED_TO_SECRET_SCAN_FILES_TYPES = ['.py', '.js', '.properties', '.pem', '.php', '.xml', '.ts', '.env', '.java', '.rb',
-                                    '.go', '.cs', '.txt'] + SUPPORTED_FILE_EXTENSIONS
+ADDED_TO_SECRET_SCAN_FILES_TYPES = SOURCE_CODE_EXTENSION + SUPPORTED_FILE_EXTENSIONS
 
 MAX_FILE_SIZE = int(os.getenv('CHECKOV_MAX_FILE_SIZE', '5000000'))  # 5 MB is default limit
 
@@ -161,16 +163,19 @@ class Runner(BaseRunner[None]):
             self.pbar.initiate(len(files_to_scan))
             self._scan_files(files_to_scan, secrets, self.pbar)
             self.pbar.close()
-
+            secrets_duplication: dict[str, bool] = {}
             for _, secret in secrets:
                 check_id = SECRET_TYPE_TO_ID.get(secret.type)
                 if not check_id:
                     continue
+                secret_key = f'{secret.filename}_{secret.line_number}_{secret.secret_hash}'
+                if secret_key in secrets_duplication:
+                    continue
+                else:
+                    secrets_duplication[secret_key] = True
                 bc_check_id = metadata_integration.get_bc_id(check_id)
                 severity = metadata_integration.get_severity(check_id)
-                if runner_filter.checks and not runner_filter.should_run_check(check_id=check_id,
-                                                                               bc_check_id=bc_check_id,
-                                                                               severity=severity):
+                if not runner_filter.should_run_check(check_id=check_id, bc_check_id=bc_check_id, severity=severity, report_type=CheckType.SECRETS):
                     continue
                 result: _CheckResult = {'result': CheckResult.FAILED}
                 line_text = linecache.getline(secret.filename, secret.line_number)
@@ -184,7 +189,9 @@ class Runner(BaseRunner[None]):
                     runner_filter=runner_filter,
                 ) or result
                 report.add_resource(f'{secret.filename}:{secret.secret_hash}')
-                line_text_censored = omit_secret_value_from_line(secret.secret_value, line_text)
+                # 'secret.secret_value' can actually be 'None', but only when 'PotentialSecret' was created
+                # via 'load_secret_from_dict'
+                line_text_censored = omit_secret_value_from_line(cast(str, secret.secret_value), line_text)
                 report.add_record(Record(
                     check_id=check_id,
                     bc_check_id=bc_check_id,
@@ -199,7 +206,6 @@ class Runner(BaseRunner[None]):
                     evaluations=None,
                     file_abs_path=os.path.abspath(secret.filename),
                 ))
-
             return report
 
     @staticmethod
@@ -207,7 +213,7 @@ class Runner(BaseRunner[None]):
         # implemented the scan function like secrets.scan_files
         base_path = secrets.root
         results = parallel_runner.run_function(
-            func=lambda f: list((Runner._safe_scan(f, base_path))),
+            func=lambda f: Runner._safe_scan(f, base_path),
             items=files_to_scan,
             run_multiprocess=os.getenv("RUN_SECRETS_MULTIPROCESS", "").lower() == "true"
         )
@@ -246,12 +252,11 @@ class Runner(BaseRunner[None]):
     def search_for_suppression(
             check_id: str,
             bc_check_id: str,
-            severity: Severity,
+            severity: Severity | None,
             secret: PotentialSecret,
             runner_filter: RunnerFilter
     ) -> _CheckResult | None:
-        if not runner_filter.should_run_check(check_id=check_id, bc_check_id=bc_check_id,
-                                              severity=severity) and check_id in CHECK_ID_TO_SECRET_TYPE.keys():
+        if not runner_filter.should_run_check(check_id=check_id, bc_check_id=bc_check_id, severity=severity, report_type=CheckType.SECRETS) and check_id in CHECK_ID_TO_SECRET_TYPE.keys():
             return {
                 "result": CheckResult.SKIPPED,
                 "suppress_comment": f"Secret scan {check_id} is skipped"
