@@ -4,6 +4,7 @@ import json
 import logging
 import os
 import re
+from collections.abc import Sequence
 from copy import deepcopy
 from json import dumps, loads
 from pathlib import Path
@@ -12,6 +13,7 @@ from typing import Optional, Dict, Mapping, Set, Tuple, Callable, Any, List, Typ
 import deep_merge
 import hcl2
 from lark import Tree
+from typing_extensions import TypeAlias
 
 from checkov.common.runners.base_runner import filter_ignored_paths, IGNORE_HIDDEN_DIRECTORY_ENV
 from checkov.common.util.config_utils import should_scan_hcl_files
@@ -26,9 +28,15 @@ from checkov.terraform.module_loading.content import ModuleContent
 from checkov.terraform.module_loading.module_finder import load_tf_modules
 from checkov.terraform.module_loading.registry import module_loader_registry as default_ml_registry, \
     ModuleLoaderRegistry
-from checkov.terraform.parser_utils import eval_string, find_var_blocks
+from checkov.common.util.parser_utils import eval_string, find_var_blocks
+
+_Hcl2Payload: TypeAlias = "dict[str, list[dict[str, Any]]]"
 
 external_modules_download_path = os.environ.get('EXTERNAL_MODULES_DIR', DEFAULT_EXTERNAL_MODULES_DIR)
+GOOD_BLOCK_TYPES = {BlockType.LOCALS, BlockType.TERRAFORM}  # used for cleaning bad tf definitions
+
+ENTITY_NAME_PATTERN = re.compile(r"[^\W0-9][\w-]*")
+RESOLVED_MODULE_PATTERN = re.compile(r"\[.+\#.+\]")
 
 
 def _filter_ignored_paths(root, paths, excluded_paths):
@@ -39,7 +47,7 @@ def _filter_ignored_paths(root, paths, excluded_paths):
 class Parser:
     def __init__(self, module_class: Type[Module] = Module):
         self.module_class = module_class
-        self._parsed_directories = set()
+        self._parsed_directories: set[str] = set()
         self.external_modules_source_map: Dict[Tuple[str, str], str] = {}
         self.module_address_map: Dict[Tuple[str, str], str] = {}
         self.loaded_files_map = {}
@@ -78,7 +86,7 @@ class Parser:
             self.env_vars = dict(os.environ)
         self.excluded_paths = excluded_paths
 
-    def _check_process_dir(self, directory):
+    def _check_process_dir(self, directory: str) -> bool:
         if directory not in self._parsed_directories:
             self._parsed_directories.add(directory)
             return True
@@ -108,7 +116,7 @@ class Parser:
         self, file: str, parsing_errors: Optional[Dict[str, Exception]] = None, scan_hcl: bool = False
     ) -> Optional[Dict[str, Any]]:
         if file.endswith(".tf") or file.endswith(".tf.json") or (scan_hcl and file.endswith(".hcl")):
-            parse_result = _load_or_die_quietly(Path(file), parsing_errors)
+            parse_result = _load_or_die_quietly(file, parsing_errors)
             if parse_result:
                 parse_result = self._serialize_definitions(parse_result)
                 parse_result = self._clean_parser_types(parse_result)
@@ -119,7 +127,7 @@ class Parser:
     def _parse_directory(self, include_sub_dirs: bool = True,
                          module_loader_registry: ModuleLoaderRegistry = default_ml_registry,
                          dir_filter: Callable[[str], bool] = lambda _: True,
-                         vars_files: Optional[List[str]] = None):
+                         vars_files: Optional[List[str]] = None) -> None:
         """
     Load and resolve configuration files starting in the given directory, merging the
     resulting data into `tf_definitions`. This loads data according to the Terraform Code Organization
@@ -316,8 +324,8 @@ class Parser:
                 # load, forcing things through without complete resolution.
                 force_final_module_load = True
 
-    def _load_files(self, files):
-        def _load_file(file):
+    def _load_files(self, files: list[os.DirEntry]):
+        def _load_file(file: os.DirEntry):
             parsing_errors = {}
             result = _load_or_die_quietly(file, parsing_errors)
             # the exceptions type can un-pickleable
@@ -536,15 +544,23 @@ class Parser:
                 try:
                     module.add_blocks(block_type, blocks[block_type], file_path, source)
                 except Exception as e:
-                    logging.error(f'Failed to add block {blocks[block_type]}. Error:')
-                    logging.error(e, exc_info=True)
+                    logging.warning(f'Failed to add block {blocks[block_type]}. Error:')
+                    logging.warning(e, exc_info=False)
         return module, tf_definitions
 
     @staticmethod
-    def _clean_parser_types(conf: dict) -> dict:
+    def _clean_parser_types(conf: dict[str, Any]) -> dict[str, Any]:
+        if not conf:
+            return conf
+
         sorted_keys = list(conf.keys())
-        if len(conf.keys()) > 0 and all(isinstance(x, type(list(conf.keys())[0])) for x in conf.keys()):
-            sorted_keys = sorted(filter(lambda x: x is not None, conf.keys()))
+        first_key_type = type(sorted_keys[0])
+        if first_key_type is None:
+            return {}
+
+        if all(isinstance(x, first_key_type) for x in sorted_keys):
+            sorted_keys.sort()
+
         # Create a new dict where the keys are sorted alphabetically
         sorted_conf = {key: conf[key] for key in sorted_keys}
         for attribute, values in sorted_conf.items():
@@ -553,7 +569,7 @@ class Parser:
             if isinstance(values, list):
                 sorted_conf[attribute] = Parser._clean_parser_types_lst(values)
             elif isinstance(values, dict):
-                sorted_conf[attribute] = Parser._clean_parser_types(conf[attribute])
+                sorted_conf[attribute] = Parser._clean_parser_types(values)
             elif isinstance(values, str) and values in ('true', 'false'):
                 sorted_conf[attribute] = True if values == 'true' else False
             elif isinstance(values, set):
@@ -563,20 +579,19 @@ class Parser:
         return sorted_conf
 
     @staticmethod
-    def _clean_parser_types_lst(values: list) -> list:
-        for i in range(len(values)):
-            val = values[i]
+    def _clean_parser_types_lst(values: list[Any]) -> list[Any]:
+        for idx, val in enumerate(values):
             if isinstance(val, dict):
-                values[i] = Parser._clean_parser_types(val)
+                values[idx] = Parser._clean_parser_types(val)
             elif isinstance(val, list):
-                values[i] = Parser._clean_parser_types_lst(val)
+                values[idx] = Parser._clean_parser_types_lst(val)
             elif isinstance(val, str):
                 if val == 'true':
-                    values[i] = True
+                    values[idx] = True
                 elif val == 'false':
-                    values[i] = False
+                    values[idx] = False
             elif isinstance(val, set):
-                values[i] = Parser._clean_parser_types_lst(list(val))
+                values[idx] = Parser._clean_parser_types_lst(list(val))
         str_values_in_lst = [val for val in values if isinstance(val, str)]
         str_values_in_lst.sort()
         result_values = [val for val in values if not isinstance(val, str)]
@@ -584,11 +599,11 @@ class Parser:
         return result_values
 
     @staticmethod
-    def _serialize_definitions(tf_definitions):
+    def _serialize_definitions(tf_definitions: dict[str, _Hcl2Payload]) -> dict[str, _Hcl2Payload]:
         return loads(dumps(tf_definitions, cls=CustomJSONEncoder))
 
     @staticmethod
-    def get_next_vertices(evaluated_files: list, unevaluated_files: list) -> (list, list):
+    def get_next_vertices(evaluated_files: list[str], unevaluated_files: list[str]) -> tuple[list[str], list[str]]:
         """
         This function implements a lazy separation of levels for the evaluated files. It receives the evaluated
         files, and returns 2 lists:
@@ -690,7 +705,7 @@ class Parser:
             dep_index_mapping=dep_index_mapping
         )
 
-    def add_tfvars(self, module, source):
+    def add_tfvars(self, module: Module, source: str) -> None:
         if not self.external_variables_data:
             return
         for (var_name, default, path) in self.external_variables_data:
@@ -706,8 +721,9 @@ class Parser:
         return dirname_path
 
 
-def _load_or_die_quietly(file: os.PathLike, parsing_errors: Dict,
-                         clean_definitions: bool = True) -> Optional[Mapping]:
+def _load_or_die_quietly(
+    file: str | Path, parsing_errors: dict[str, Exception], clean_definitions: bool = True
+) -> _Hcl2Payload | None:
     """
 Load JSON or HCL, depending on filename.
     :return: None if the file can't be loaded
@@ -719,7 +735,7 @@ Load JSON or HCL, depending on filename.
     try:
         logging.debug(f"Parsing {file_path}")
 
-        with open(file_path, "r") as f:
+        with open(file_path, "r", encoding="utf-8-sig") as f:
             if file_name.endswith(".json"):
                 return json.load(f)
             else:
@@ -735,35 +751,37 @@ Load JSON or HCL, depending on filename.
         return None
 
 
-def _is_valid_block(block):
+def _is_valid_block(block: Any) -> bool:
     if not isinstance(block, dict):
         return True
 
     # if the block is empty, there's no need to process it further
-    if len(block) == 0:
+    if not block:
         return False
 
-    entity_name, _ = next(iter(block.items()))
-    if re.fullmatch(r'[^\W0-9][\w-]*', entity_name):
+    entity_name = next(iter(block.keys()))
+    if re.fullmatch(ENTITY_NAME_PATTERN, entity_name):
         return True
     return False
 
 
-def validate_malformed_definitions(raw_data):
-    raw_data_cleaned = raw_data
-    for block_type, blocks in raw_data.items():
-        raw_data_cleaned[block_type] = [block for block in blocks if _is_valid_block(block)]
-
-    return raw_data_cleaned
-
-
-def clean_bad_definitions(tf_definition_list):
+def validate_malformed_definitions(raw_data: _Hcl2Payload) -> _Hcl2Payload:
     return {
-        block_type: list(filter(lambda definition_list: block_type in [BlockType.LOCALS, BlockType.TERRAFORM] or
-                                                        not isinstance(definition_list, dict)
-                                                        or len(definition_list.keys()) == 1,
-                                tf_definition_list[block_type]))
-        for block_type in tf_definition_list.keys()
+        block_type: [block for block in blocks if _is_valid_block(block)]
+        for block_type, blocks in raw_data.items()
+    }
+
+
+def clean_bad_definitions(tf_definition_list: _Hcl2Payload) -> _Hcl2Payload:
+    return {
+        block_type: [
+            definition
+            for definition in definition_list
+            if block_type in GOOD_BLOCK_TYPES
+               or not isinstance(definition, dict)
+               or len(definition) == 1
+        ]
+        for block_type, definition_list in tf_definition_list.items()
     }
 
 
@@ -774,18 +792,17 @@ def _to_native_value(value: str) -> Any:
         return eval_string(value)
 
 
-def _remove_module_dependency_in_path(path):
+def _remove_module_dependency_in_path(path: str) -> str:
     """
     :param path: path that looks like "dir/main.tf[other_dir/x.tf#0]
     :return: only the outer path: dir/main.tf
     """
-    resolved_module_pattern = re.compile(r'\[.+\#.+\]')
-    if re.findall(resolved_module_pattern, path):
-        path = re.sub(resolved_module_pattern, '', path)
+    if re.findall(RESOLVED_MODULE_PATTERN, path):
+        path = re.sub(RESOLVED_MODULE_PATTERN, '', path)
     return path
 
 
-def _safe_index(sequence_hopefully, index) -> Optional[Any]:
+def _safe_index(sequence_hopefully: Sequence[Any], index: int) -> Any:
     try:
         return sequence_hopefully[index]
     except IndexError:
